==> cohesity_management_sdk-1.11.2.tar.gz: cohesity_management_sdk-1.11.2/cohesity_management_sdk/models_v2/nlm_lock.py <==
# -*- coding: utf-8 -*-

import cohesity_management_sdk.models_v2.lock_range

class NlmLock(object):

    """Implementation of the 'NlmLock' model.

    Specifies a NLM lock.

    Attributes:
        client_id (int): Specifies the client_id of an entity lock.
        lock_ranges (list  of LockRange): Specifies the list of lock ranges.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "client_id":'clientId',
        "lock_ranges":'lockRanges'
    }

    def __init__(self,
                 client_id=None,
                 lock_ranges=None):
        """Constructor for the NlmLock class"""

        # Initialize members of the class
        self.client_id = client_id
        self.lock_ranges = lock_ranges


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        client_id = dictionary.get('clientId')
        lock_ranges = None
        if dictionary.get('lockRanges') != None:
            lock_ranges = list()
            for structure in dictionary.get('lockRanges'):
                lock_ranges.append(cohesity_management_sdk.models_v2.lock_range.LockRange.from_dictionary(structure))

        # Return an object of this model
        return cls(client_id,
                   lock_ranges)

==> cohesity_management_sdk-1.12.3.tar.gz: cohesity_management_sdk-1.12.3/cohesity_management_sdk/models_v2/nlm_lock.py <==
# -*- coding: utf-8 -*-

import cohesity_management_sdk.models_v2.lock_range

class NlmLock(object):

    """Implementation of the 'NlmLock' model.

    Specifies a NLM lock.

    Attributes:
        client_id (int): Specifies the client_id of an entity lock.
        lock_ranges (list  of LockRange): Specifies the list of lock ranges.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "client_id":'clientId',
        "lock_ranges":'lockRanges'
    }

    def __init__(self,
                 client_id=None,
                 lock_ranges=None):
        """Constructor for the NlmLock class"""

        # Initialize members of the class
        self.client_id = client_id
        self.lock_ranges = lock_ranges


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        client_id = dictionary.get('clientId')
        lock_ranges = None
        if dictionary.get("lockRanges") is not None:
            lock_ranges = list()
            for structure in dictionary.get('lockRanges'):
                lock_ranges.append(cohesity_management_sdk.models_v2.lock_range.LockRange.from_dictionary(structure))

        # Return an object of this model
        return cls(client_id,
                   lock_ranges)
